@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2013-2017, Camptocamp SA
+# Copyright (c) 2012-2020, Camptocamp SA
 # All rights reserved.
 
 # Redistribution and use in source and binary forms, with or without
@@ -26,11 +26,11 @@
 # The views and conclusions contained in the software and documentation are those
 # of the authors and should not be interpreted as representing official policies,
 # either expressed or implied, of the FreeBSD Project.
-from typing import Optional
+import json
+from typing import Any, Optional, Type
 
 from sqlalchemy.engine import Dialect
-from sqlalchemy.types import TypeDecorator, VARCHAR
-import json
+from sqlalchemy.types import VARCHAR, TypeDecorator, UserDefinedType
 
 
 # get from https://docs.sqlalchemy.org/en/latest/orm/extensions/
@@ -49,3 +49,23 @@ class JSONEncodedDict(TypeDecorator):
     @staticmethod
     def process_result_value(value: Optional[str], _: Dialect) -> Optional[dict]:
         return json.loads(value) if value is not None else None
+
+    @property
+    def python_type(self) -> Type:
+        return dict
+
+    @staticmethod
+    def process_literal_param(value: str, dialect: Any) -> str:
+        del dialect
+        return json.dumps(value)
+
+
+class TsVector(UserDefinedType):
+    """ A custom type for PostgreSQL's tsvector type. """
+
+    def get_col_spec(self) -> str:  # pylint: disable=no-self-use
+        return "TSVECTOR"
+
+    @property
+    def python_type(self) -> Type:
+        return dict
